pymta
=======

pymta is a library to build a custom SMTP server in Python. This is useful if you want to

 * test mail-sending code against a real SMTP server even in your unit tests.
 * build a custom SMTP server with non-standard behavior without reimplementing the whole SMTP protocol.
 * have a low-volume SMTP server which can be easily extended using Python


